* Encoding: windows-1252.

****************************************************************************************************************************************.
****************************************************************************************************************************************.
*SYNTAX FOR CREATING SHDI DATASET FROM STARTING DATA FILE.
****************************************************************************************************************************************.
****************************************************************************************************************************************.

*DEFINE FILE DIRECTORY.
cd 't:\temp'.

****************************************************************************************************************************************.
*CREATE INDICATOR FOR AVAILABILITY/MISSING OF INDICATORS.
****************************************************************************************************************************************.
get file='SHDI-Start.sav'.
freq country year.

*REMOVE VARIABLES THAT ARE NOT NEEDED.
delete variables source1 source2 nregions.

compute miss=-9.
if (esch>0 and msch>0 and lgnic>0 and lifexp>0) miss=0.
if (miss=-9 and esch>0 and msch>0 and lifexp>0) miss=1.
if (miss=-9 and lgnic>0 and esch>0 and msch>0) miss=2.
if (miss=-9 and lgnic>0 and msch>0 and lifexp>0) miss=3.
if (miss=-9 and lgnic>0 and esch>0 and lifexp>0) miss=4.
if (miss=-9 and esch>0 and msch>0) miss=5.
if (miss=-9 and msch>0 and lifexp>0) miss=6.
if (miss=-9 and esch>0 and lifexp>0) miss=7.
if (miss=-9 and lgnic>0 and msch>0) miss=8.
if (miss=-9 and lgnic>0 and esch>0) miss=9.
if (miss=-9 and lgnic>0 and lifexp>0) miss=10.
if (miss=-9 and lgnic>0) miss=11.
if (miss=-9 and lifexp>0) miss=12.
if (miss=-9 and esch>0) miss=13.
if (miss=-9 and msch>0) miss=14.
if (miss=-9) miss=15.

var lab miss 'Combination of missing indicators'.
val lab miss 
0'None missing' 
1'GNIc missing' 
2'Life expectancy missing' 
3'Expected school missing' 
4'Years school missing'
5'GNIc and life expectancy missing' 
6'GNIc and expected school missing' 
7'GNIc and years school missing'
8'Life expectancy and expected school missing' 
9'Life expectancy and years school missing'
10'Expected and years school missing' 
11'Only GNIc present' 
12'Only life expectancy present'
13'Only expected school present' 
14'Only years school present' 
15'All indicators missing'.
freq miss.

*SAVE DATAFILE AND REGION CHARACTERISTICS FOR LATER ADDITION.
sort cases by gdlcode year.
save outfile='SHDI Combined.sav'.
compute selx=0.
if (gdlcode=lag(gdlcode,1)) selx=1.
freq selx.
sel if selx=0.
save outfile='regchar.sav'
/keep=country iso_code gdlcode level region.

****************************************************************************************************************************************.
*CREATE FOR ALL REGIONS DATA FROM 1990-2017.
****************************************************************************************************************************************.
GET FILE='SHDI combined.sav'
 /keep=gdlcode year miss.
freq miss year.

sort cases by gdlcode year.
SPLIT FILE BY gdlcode.
CASESTOVARS
/ID=gdlcode
/INDEX=year.

recode miss.1990.00 to miss.2017.00 (missing=-9).
freq miss.2017.00.

VARSTOCASES
  /MAKE missx FROM miss.1990.00 to miss.2017.00
  /INDEX=year(missx) 
  /NULL=KEEP.
freq missx.

*change year variable from string to numeric.
if year = "miss.1990.00" year = "1990".
if year = "miss.1991.00" year = "1991".
if year = "miss.1992.00" year = "1992".
if year = "miss.1993.00" year = "1993".
if year = "miss.1994.00" year = "1994".
if year = "miss.1995.00" year = "1995".
if year = "miss.1996.00" year = "1996".
if year = "miss.1997.00" year = "1997".
if year = "miss.1998.00" year = "1998".
if year = "miss.1999.00" year = "1999".
if year = "miss.2000.00" year = "2000".
if year = "miss.2001.00" year = "2001".
if year = "miss.2002.00" year = "2002".
if year = "miss.2003.00" year = "2003".
if year = "miss.2004.00" year = "2004".
if year = "miss.2005.00" year = "2005".
if year = "miss.2006.00" year = "2006".
if year = "miss.2007.00" year = "2007".
if year = "miss.2008.00" year = "2008".
if year = "miss.2009.00" year = "2009".
if year = "miss.2010.00" year = "2010".
if year = "miss.2011.00" year = "2011".
if year = "miss.2012.00" year = "2012".
if year = "miss.2013.00" year = "2013".
if year = "miss.2014.00" year = "2014".
if year = "miss.2015.00" year = "2015".
if year = "miss.2016.00" year = "2016".
if year = "miss.2017.00" year = "2017".
alter type year(f2).

*ADD TO ORIGINAL SAVED DATA.
sort cases by gdlcode year.
match files file=*
/table='SHDI Combined.sav'
/by gdlcode year
/drop=miss country iso_code  level region.
rename var (missx=miss).
recode miss (-9=15).
freq miss.

*ADD OTHER CHARATERISTICS OF REGIONS.
match files file=*
/table='regchar.sav'
/by gdlcode.
freq miss year.

*TEMPORARY SAVE AND REORDER FILE.
SAVE OUTFILE="HDI Subn Data All.sav"
 /keep=iso_code country year gdlcode level region esch msch lgnic lifexp regpop miss.

****************************************************************************************************************************************.
*ESTIMATE PRECEDING AND SUCCEEDING YEARS BY INTERPOLATION AND EXTRAPOLATION.
****************************************************************************************************************************************.
GET FILE="HDI Subn Data All.sav".

*INTERPOLATION AND EXTRAPOLATION EXPECTED SCHOOLING.
recode miss (3,6,8,10,11,12,14,15=1)(else=0) into misp.
compute indic=esch.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert-intra-extra-polation-SHDI.sps'.
rename var (pol=polesch)(yrpol=yrpolesch).
compute esch=est.
var lab polesch 'Expected schooling inter or extrapolated' /yrpolesch 'Years over which expected schooling is inter or extrapolated'
/esch 'Real or estimated value expected schooling'.

*INTERPOLATION AND EXTRAPOLATION MEAN SCHOOLING.
recode miss (4,7,9,10,11,12,13,15=1)(else=0) into misp.
sort cased by gdlcode year.
compute indic=msch.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert-intra-extra-polation-SHDI.sps'.
rename var (pol=polmsch)(yrpol=yrpolmsch).
compute msch=est.
var lab polmsch 'Years schooling inter or extrapolated' /yrpolmsch 'Years over which years schooling is inter or extrapolated'
/msch 'Real or estimated value years schooling'.

*INTERPOLATION AND EXTRAPOLATION LGNIC.
recode miss (1,5,6,7,12,13,14,15=1)(else=0) into misp.
sort cased by gdlcode year.
compute indic=lgnic.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert-intra-extra-polation-SHDI.sps'.
rename var (pol=pollgnic)(yrpol=yrpollgnic).
compute lgnic=est.
var lab pollgnic 'LGNIc inter or extrapolated' /yrpollgnic 'Years over which LGNIc is inter or extrapolated'
/lgnic 'Real or estimated value LGNIc'.

*INTERPOLATION AND EXTRAPOLATION LIFE EXPECTANCY.
recode miss (2,5,8,9,11,13,14,15=1)(else=0) into misp.
sort cased by gdlcode year.
compute indic=lifexp.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert-intra-extra-polation-SHDI.sps'.
rename var (pol=pollex)(yrpol=yrpollex).
compute lifexp=est.
var lab pollex 'Life expectancy inter or extrapolated' /yrpollex 'Years over which life expectancy is inter or extrapolated'
/lifexp 'Real or estimated value life expectancy'.

*INTERPOLATION AND EXTRAPOLATION REGIONAL POPULATION.
recode regpop (missing,-9=1)(else=0) into misp.
sort cased by gdlcode year.
compute indic=regpop.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert-intra-extra-polation-SHDI.sps'.
rename var (pol=polpop)(yrpol=yrpolpop).
compute pop=est.
var lab polpop 'Population inter or extrapolated' /yrpolpop 'Years over which population is inter or extrapolated'
/pop 'Real or estimated value population'.

sort cases by gdlcode year.
SAVE OUTFILE="HDI Polation by indicator.sav"
/keep=iso_code  country gdlcode year level region miss esch polesch yrpolesch msch polmsch yrpolmsch
 lgnic pollgnic yrpollgnic lifexp pollex yrpollex pop polpop yrpolpop.

***********************************************************************************.
*ADD INDICATORS UNDP HDI WEBSITE AT NATIONAL LEVEL.
***********************************************************************************.
GET FILE="HDI Polation by indicator.sav".
freq iso_code.
sort cases by iso_code year.
match files file=*
/table='UNDP-HDI-Data-2017.sav'
/by iso_code year.
descr hdiun.
recode hdiun lifexpun gnicun expschun yrschun popun (missing=-9).

***********************************************************************************.
*ADD NATIONAL VALUES FOR COUNTRIES NOT IN UNDP DATA.
***********************************************************************************.
*KOSOVO FROM NATIONAL HUMAN DEVELOPMENT REPORT 2016. 
if (iso_code="XKO" and (year=2016 or year=2017)) lifexpun=71.1.
if (iso_code="XKO" and (year=2016 or year=2017)) gnicun=9796.
if (iso_code="XKO" and (year=2016 or year=2017)) expschun=14.2.
if (iso_code="XKO" and (year=2016 or year=2017)) yrschun=10.7.
if (iso_code="XKO" and (year=2016 or year=2017)) popun=1.813.

*SOMALIA NATIONAL DATA FROM GDL-AD FOR 2006.
*AND FROM NATIONAL HUMAN DEVELOPMENT REPORT FOR 2012.
*BETWEEN 2006 AND 2012 INTERPOLATION.
*AFTER 2012 EXTRAPOLATION FOLLOWING TREND IN (LOG)GNIC FROM THE WORLD DEVELOPMENT INDICATORS.

*GNIC.
if (iso_code="SOM" and year=2006) gnicun=1422.
if (iso_code="SOM" and year=2007) gnicun=1326.
if (iso_code="SOM" and year=2008) gnicun=1229.
if (iso_code="SOM" and year=2009) gnicun=1133.
if (iso_code="SOM" and year=2010) gnicun=1036.
if (iso_code="SOM" and year=2011) gnicun=940.
if (iso_code="SOM" and year=2012) gnicun=843.
if (iso_code="SOM" and year=2013) gnicun=881.
if (iso_code="SOM" and year=2014) gnicun=947.
if (iso_code="SOM" and year=2015) gnicun=1063.
if (iso_code="SOM" and year=2016) gnicun=1134.
if (iso_code="SOM" and year=2017) gnicun=1205.

*MEAN SCHOOLING 25+.
if (iso_code="SOM" and year=2006) yrschun=2.03.
if (iso_code="SOM" and year=2007) yrschun=2.50.
if (iso_code="SOM" and year=2008) yrschun=2.96.
if (iso_code="SOM" and year=2009) yrschun=3.43.
if (iso_code="SOM" and year=2010) yrschun=3.89.
if (iso_code="SOM" and year=2011) yrschun=4.36.
if (iso_code="SOM" and year=2012) yrschun=4.82.
if (iso_code="SOM" and year=2013) yrschun=4.85.
if (iso_code="SOM" and year=2014) yrschun=4.90.
if (iso_code="SOM" and year=2015) yrschun=4.99.
if (iso_code="SOM" and year=2016) yrschun=5.03.
if (iso_code="SOM" and year=2017) yrschun=5.08.

*EXPECTED SCHOOLING AGE 6.
if (iso_code="SOM" and year=2006) expschun=7.74.
if (iso_code="SOM" and year=2007) expschun=6.75.
if (iso_code="SOM" and year=2008) expschun=5.76.
if (iso_code="SOM" and year=2009) expschun=4.77.
if (iso_code="SOM" and year=2010) expschun=3.78.
if (iso_code="SOM" and year=2011) expschun=2.79.
if (iso_code="SOM" and year=2012) expschun=1.8.
if (iso_code="SOM" and year=2013) expschun=1.81.
if (iso_code="SOM" and year=2014) expschun=1.83.
if (iso_code="SOM" and year=2015) expschun=1.86.
if (iso_code="SOM" and year=2016) expschun=1.88.
if (iso_code="SOM" and year=2017) expschun=1.90.

*LIFE EXPECTANCY.
if (iso_code="SOM" and year=2006) lifexpun=53.3.
if (iso_code="SOM" and year=2007) lifexpun=52.9.
if (iso_code="SOM" and year=2008) lifexpun=52.4.
if (iso_code="SOM" and year=2009) lifexpun=52.0.
if (iso_code="SOM" and year=2010) lifexpun=51.7.
if (iso_code="SOM" and year=2011) lifexpun=51.1.
if (iso_code="SOM" and year=2012) lifexpun=50.7.
if (iso_code="SOM" and year=2013) lifexpun=51.0.
if (iso_code="SOM" and year=2014) lifexpun=51.6.
if (iso_code="SOM" and year=2015) lifexpun=52.4.
if (iso_code="SOM" and year=2016) lifexpun=52.9.
if (iso_code="SOM" and year=2017) lifexpun=53.4.

********************************************************************.
* IMPROVE VARIABLES AND COMPUTE SHDI.
********************************************************************.
*SUBSTITUTE VALUES MSCH FOR COUNTRIES WHERE ESCH IS MISSING.
*BECAUSE OF TRANSLATION TO NATIONAL UNDP VALUES ONLY VARIATION IN MSCH IS USED.
freq esch.
*recode esch (missing=1)(else=0) into eschmis.
if (iso_code='AUS') esch=msch.
if (iso_code='CHL') esch=msch.
if (iso_code='CPV') esch=msch.
if (iso_code='ECU') esch=msch.
if (iso_code='IRL') esch=msch.
if (iso_code='CAN') esch=msch.
if (iso_code='CHN') esch=msch.
if (iso_code='CUB') esch=msch.
if (iso_code='EST') esch=msch.
if (iso_code='GNQ') esch=msch.
if (iso_code='HRV') esch=msch.
if (iso_code='JPN') esch=msch.
if (iso_code='KOR') esch=msch.
if (iso_code='KWT') esch=msch.
if (iso_code='LBN') esch=msch.
if (iso_code='LBY') esch=msch.
if (iso_code='LTU') esch=msch.
if (iso_code='MLT') esch=msch.
if (iso_code='MUS') esch=msch.
if (iso_code='NZL') esch=msch.
if (iso_code='RUS') esch=msch.
if (iso_code='SAU') esch=msch.
if (iso_code='SVN') esch=msch.
if (iso_code='USA') esch=msch.
if (gdlcode='FRAr129') msch=esch.

*COUNTRIES FOR WHICH LIFEXP IS MISSING.
*USE NATIONAL VALUE UNDP.
if (iso_code='ARG') lifexp=lifexpun.
if (iso_code='BIH') lifexp=lifexpun.
if (iso_code='BRB') lifexp=lifexpun.
if (iso_code='CPV') lifexp=lifexpun.
if (iso_code='CRI') lifexp=lifexpun.
if (iso_code='ECU') lifexp=lifexpun.
if (iso_code='HRV') lifexp=lifexpun.
if (iso_code='KWT') lifexp=lifexpun.
if (iso_code='LBN') lifexp=lifexpun.
if (iso_code='LBY') lifexp=lifexpun.
if (iso_code='MLT') lifexp=lifexpun.
if (iso_code='MUS') lifexp=lifexpun.
if (iso_code='MYS') lifexp=lifexpun.
if (iso_code='PAN') lifexp=lifexpun.
if (iso_code='SAU') lifexp=lifexpun.
if (iso_code='URY') lifexp=lifexpun.

*COUNTRIES FOR WHICH LGNIC IS MISSING.
*USE NATIONAL VALUE UNDP.
if (iso_code='CUB') lgnic=ln(gnicun).

*COUNTRIES FOR WHICH BOTH MSCH AND ESCH ARE MISSING.
*USE NATIONAL VALUES UNDP.
if (iso_code='LVA') msch=yrschun.
if (iso_code='LVA') esch=expschun.

*REMOVE COUNTRY-YEARS FOR WHICH NO UNDP VALUES AVAILABLE.
compute yearsel=0.
if (iso_code='AFG' and year<2002) yearsel=1.
if (iso_code='AGO' and year<1999) yearsel=1.
if (iso_code='AND' and year<2010) yearsel=1.
if (iso_code='ATG' and year<2005) yearsel=1.
if (iso_code='AZE' and year<1995) yearsel=1.
if (iso_code='BFA' and year<2005) yearsel=1.
if (iso_code='BHS' and year<2000) yearsel=1.
if (iso_code='BIH' and year<2005) yearsel=1.
if (iso_code='BLR' and year<1995) yearsel=1.
if (iso_code='BTN' and year<2010) yearsel=1.
if (iso_code='COD' and year=1992) yearsel=1.
if (iso_code='COM' and year<2004) yearsel=1.
if (iso_code='CPV' and year<2000) yearsel=1.
if (iso_code='DJI' and year<1995) yearsel=1.
if (iso_code='DMA' and year<2000) yearsel=1.
if (iso_code='ERI' and year<2005) yearsel=1.
if (iso_code='ETH' and year<2000) yearsel=1.
if (iso_code='FSM' and year<2000) yearsel=1.
if (iso_code='GEO' and year<2000) yearsel=1.
if (iso_code='GNB' and year<2005) yearsel=1.
if (iso_code='GNQ' and year<2000) yearsel=1.
if (iso_code='GRD' and year<2010) yearsel=1.
if (iso_code='HUN' and year=1992) yearsel=1.
if (iso_code='KAZ' and year=1992) yearsel=1.
if (iso_code='KIR' and year<2005) yearsel=1.
if (iso_code='KNA' and year<2010) yearsel=1.
if (iso_code='LBN' and year<2005) yearsel=1.
if (iso_code='LBR' and year<1999) yearsel=1.
if (iso_code='LCA' and year<2000) yearsel=1.
if (iso_code='LIE' and year<2000) yearsel=1.
if (iso_code='MDG' and year<2000) yearsel=1.
if (iso_code='MDV' and year<1995) yearsel=1.
if (iso_code='MKD' and year<2005) yearsel=1.
if (iso_code='MNE' and year<2003) yearsel=1.
if (iso_code='NGA' and year<2003) yearsel=1.
if (iso_code='OMN' and year<2000) yearsel=1.
if (iso_code='PSE' and year<2004) yearsel=1.
if (iso_code='SLB' and year<1999) yearsel=1.
if (iso_code='SOM' and year<2006) yearsel=1.
if (iso_code='SSD' and year<2010) yearsel=1.
if (iso_code='SUR' and year<2004) yearsel=1.
if (iso_code='SYR' and year=1990) yearsel=1.
if (iso_code='TCD' and year<2000) yearsel=1.
if (iso_code='TKM' and year<2010) yearsel=1.
if (iso_code='UZB' and year<2000) yearsel=1.
if (iso_code='VCT' and year<2000) yearsel=1.
if (iso_code='VUT' and year<2005) yearsel=1.
if (iso_code='XKO' and year<2014) yearsel=1.

*REMOVE WAR YEARS SYRIA.
if (iso_code='SYR' and year>2011) yearsel=1.

*REMOVE EAST TIMOR FROM INDONESIA.
if (iso_code='TLS' and year<2002) yearsel=1.
if (gdlcode='IDNr119' and year>2001) yearsel=1.

freq yearsel.
sel if (yearsel=0).
execute.

*****************************************************************************************************.
*USE VARIATION IN INDICATORS AND NATIONAL VALUE TO CREATE SHARE OF REGION. 
*AND USE THIS TO GET INDICATORS WITH NATIONAL UNDP VALUE AS MEAN.
*****************************************************************************************************.
*POPULATION.
compute natval=popun*1000.
compute indic=pop.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert apply national mean.sps'.
rename var (natind=popnat)(indest=popest).
var lab popest 'Population variation applied to population UNDP' /popnat 'National value population size'.
missing values popest (-9).
compute popdif=popest-pop.
execute.

*LOG GNIc.
freq gnicun.
missing values gnicun (-9).
compute natval=ln(gnicun).
compute indic=lgnic.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert apply national mean.sps'.
rename var (natind=lgnicnat)(indest=lgnicest).
var lab lgnicest 'LGNIC variation applied to LGNIC UNDP' /lgnicnat 'National value LGNIc'.
compute lgnicdif=lgnicest-lgnic.
execute.

*LIFE EXPECTANCY.
compute natval=lifexpun.
compute indic=lifexp.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert apply national mean.sps'.
rename var (natind=lifexpnat)(indest=lifexpest).
var lab lifexpest 'Life expectancy variation applied to life expectancy UNDP' /lifexpnat 'National value life expectancy'.
missing values lifexpest (-9).
compute lexpdif=lifexpest-lifexp.
exec.

*YEARS SCHOOLING 25+.
compute natval=yrschun.
compute indic=msch.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert apply national mean.sps'.
*REDUCE VARIATION IN SOUTH SUDAN TO PREVENT EDUYRS BECOME TOO HIGH.
if (iso_code='SSD') indest=natval*sqr(indshare).
rename var (natind=mschnat)(indest=mschest).
var lab mschest 'Years schooling variation applied to years schooling UNDP' /mschnat 'National value education years'.
missing values mschest (-9).
compute mschdif=mschest-msch.
exec.

*EXPECTED SCHOOLING 6+.
compute natval=expschun.
compute indic=esch.
insert file='s:\areadatabase\Human development Index Calculation\Data\Insert\Insert apply national mean.sps'.
rename var (natind=eschnat)(indest=eschest).
var lab eschest 'Expected schooling variation applied to expected schooling UNDP' /eschnat 'National value education years'.
missing values eschest (-9).
compute eschdif=eschest-esch.
execute.

*IMPROVE STRANGELY HIGH VALUES OF REGIONS BY USING NATIONAL DATA.
if (region='Agadez' or region='Diffa') lifexp=lifexpnat.
if (gdlcode='TJKr105') lifexp=lifexpnat.
if (gdlcode='TJKr105') mschest=mschnat.
if (gdlcode='TJKr105') esch=eschnat.

*FOR KOSOVO REMOVE DATA BEFORE 2016 AS NO UNDP VALUE AVAILABLE.
compute yearsel=0.
if (iso_code='XKO' and year<2016) yearsel=1.
sel if yearsel=0.
execute.
delete var natval indic indshare popdif lgnicdif lexpdif mschdif eschdif.  

*****************************************************************************************************.
*CONSTRUCT HDI COMPONENTS.
*****************************************************************************************************.
*EDUCATIONAL INDEX.
descr msch mschest esch eschest.
if (eschest>18) eschest=18.
if (mschest>15) mschest=15.
*freq eschest mschest.

*ROUND IN SAME WAY AS IN UNDP DATABASE.
compute eschest=rnd(eschest*10)/10.
compute mschest=rnd(mschest*10)/10.
*freq eschest mschest.

*CREATE INDEX.
compute eschi=eschest/18.
compute mschi=mschest/15.
compute edindex=(eschi+mschi)/2.
var lab eschi 'Expected years of education index'
/mschi 'Mean years of education index adults 25+'
/edindex 'HDI Education Index'.
*freq eschi mschi edindex.
 
*INCOME INDEX.
compute gnicest=exp(lgnicest).
descr lgnicest gnicest.
compute incindex=(lgnicest-ln(100))/(ln(75000)-ln(100)).
*GIVE VALUES OVER 1 THE VALUE 1.
if (incindex>1) incindex=1.
var lab incindex 'HDI Income Index'. 
*freq incindex.

*HEALTH INDEX.
descr lifexpest.
compute lifexpest=rnd(lifexpest*10)/10.
compute healthindex=(lifexpest-20)/(85-20).
var lab healthindex 'HDI Health Index'.
*freq healthindex.

*ROUND INDICES.
compute healthindex=rnd(healthindex*1000)/1000.
compute incindex=rnd(incindex*1000)/1000.
compute edindex=rnd(edindex*1000)/1000.
descr edindex healthindex incindex.

*COMPUTE SHDI.
compute shdi=(incindex*healthindex*edindex)**(1/3).
compute shdiadd=(incindex+healthindex+edindex)/3.
descr shdi shdiadd.

*LABELS.
var lab iso_code 'Three digit ISO code of country'
/country 'Name of country'
/year 'Year'
/level 'National or subnational'
/region 'Name of geographic region'
/miss 'Combination of missing indicators'
/popest 'Population size in thousands'
/lifexpest 'Life expectancy at birth in years'
/mschest 'Mean years of schooling 25+ population'
/eschest 'Expexted years of schooling children aged 6'
/gnicest 'Gross national income per capita in 2011 US$ PPP based on LGNIc'
/lgnicest 'Log gross national income per capita in 2011 US$ PPP'
/shdi 'Subnational Human Development Index'
/shdiadd 'Human Development Index (additive version)'.

*IMPROVE LAYOUT VARIABLES.
alter type shdi incindex healthindex edindex (F8.3) year (f2).

save outfile="SHDI-2017.sav".

***************************************.
*CREATE SHDI DATASETS.
***************************************.
get file='SHDI-2017.sav'
/keep=iso_code  country year gdlcode level region shdi healthindex incindex edindex  
 lifexpest lgnicest eschest mschest popest
/rename=(eschest mschest lifexpest lgnicest popest=esch msch lifexp lgnic pop)

*ROUND VARIABLES.
do repeat vari=edindex incindex healthindex shdi esch msch lifexp lgnic pop.
compute vari=rnd(vari*1000)/1000.
end repeat.
descr edindex incindex healthindex shdi esch msch lifexp lgnic pop.

sort cases by iso_code year gdlcode.

*EXCEL.
SAVE TRANSLATE OUTFILE='SHDI-Database.xlsx'
  /TYPE=XLS
  /VERSION=12 
  /MAP 
  /FIELDNAMES VALUE=NAMES 
  /CELLS=VALUES 
  /REPLACE.

*STATA.
SAVE TRANSLATE OUTFILE='SHDI-Database.dta'
  /TYPE=STATA 
  /VERSION=12 
  /EDITION=SE 
  /MAP 
  /REPLACE.  

*SPSS.
SAVE OUTFILE='SHDI-Database.sav'.

***********************************************************************************************************************************.
*SAVE DATASETS WITH INFORMATION ON POLATION AFTER ADJUSTING TO NATIONAL UNDP VALUES.
***********************************************************************************************************************************.
get file="SHDI-2017.sav"
/keep=iso_code  country year gdlcode level region miss pollgnic yrpollgnic pollex yrpollex polesch yrpolesch polmsch yrpolmsch
/rename=(pollgnic yrpollgnic pollex yrpollex polesch yrpolesch polmsch yrpolmsch=lgnic_polated lgnic_polyears
lifexp_polated lifexp_polyears esch_polated esch_polyears msch_polated msch_polyears).

SAVE OUTFILE='SHDI-Data-Quality.sav'. 

SAVE TRANSLATE OUTFILE='SHDI-Data-Quality.xlsx' 
  /TYPE=XLS
  /VERSION=12 
  /MAP 
  /FIELDNAMES VALUE=NAMES 
  /CELLS=VALUES 
  /REPLACE.

SAVE TRANSLATE OUTFILE='SHDI-Data-Quality.dta' 
  /TYPE=STATA 
  /VERSION=12 
  /EDITION=SE 
  /MAP 
  /REPLACE. 

******************************************************************************************.
*COMPARE COMPUTED NATIONAL SHDI VALUES WITH UN HDI VALUE.
******************************************************************************************.
get file='SHDI-2017.sav'
/keep=country year level hdiun shdi.
sel if (level='National').
freq level.
compute dif=hdiun-shdi.
temp.
sel if hdiun>0.
freq dif.
